@@ -38,8 +38,8 @@ impl Dict {
     }
 
     /// Delete a key.
-    pub fn delete(&self, key: &[u8]) -> Result<()> {
-        self.inner.delete(key)
+    pub fn remove(&self, key: &[u8]) -> Result<Option<Bytes>> {
+        self.inner.remove(key)
     }
 
     /// Create a new mapping based on a table name.
@@ -122,7 +122,7 @@ impl<'a> Transaction<'a> {
     }
 
     /// Delete a key.
-    pub fn delete(&mut self, key: impl AsRef<[u8]>) -> Result<()> {
+    pub fn remove(&mut self, key: impl AsRef<[u8]>) -> Result<()> {
         self.cache.remove(key.as_ref());
         self.to_write
             .push((Bytes::copy_from_slice(key.as_ref()), None));
@@ -282,14 +282,17 @@ impl DictInner {
     }
 
     /// Deletes a key.
-    fn delete(&self, key: &[u8]) -> Result<()> {
+    fn remove(&self, key: &[u8]) -> Result<Option<Bytes>> {
         let mut cache = self.cache.write();
-        cache.remove(key);
+        let previous = match cache.remove(key) {
+            None => self.read_uncached(&key)?,
+            Some(val) => Some(val.value),
+        };
         // we now signal the background thread
         self.send_change
             .send(SyncInstruction::Delete(Bytes::copy_from_slice(key)))
             .map_err(|_| DbError::WriteThreadFailed)?;
-        Ok(())
+        Ok(previous)
     }
 
     /// Writes a key-value pair, returning the previous value
